==> haskell-data-dword-0.3.2.1-183.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-Etw3X3VgSqh8bxGGtukvQ5
key:                  data-dword-0.3.2.1-Etw3X3VgSqh8bxGGtukvQ5
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  892f79076df5438fcbca39a8e7f13aad
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-Etw3X3VgSqh8bxGGtukvQ5
depends:
    base-4.18.2.1 data-bword-0.1.0.2-54mDQL8mvky5Hcxf1uuJzV
    ghc-prim-0.10.0 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.2.1-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-B7lOaQm5BeP18AmlmArfWW
key:                  data-dword-0.3.2.1-B7lOaQm5BeP18AmlmArfWW
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  70239f4045b443455725858fcb44817b
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-B7lOaQm5BeP18AmlmArfWW
depends:
    base-4.18.2.1 data-bword-0.1.0.2-54mDQL8mvky5Hcxf1uuJzV
    ghc-prim-0.10.0 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
